@@ -28,10 +28,11 @@ __usage__ = """
 usage:
 
 - Just use your gesture to call up the command wheel when you want to call one of your included programs.
+- Left-click the program to start it. You can also press the key shown in the programs tooltip for the same effect. 
 - Right-click an item to edit it. Middle-click an item to add a new one after it (clockwise).
 - Make folders by using the action [("kreversi", None), ("icon", "action"), ("icon2", "action2"), ...].
-  Actions are simply the commands you'd use on the commandline.
-- call "pyrad.py --quit" to shutdown the process in the background. "pyrad.py --help" shows the usage. "pyrad.py --daemon" starts pyRad without showing the GUI.
+  Actions are simply the commands you'd use on the commandline (no shell scripting though).
+- call "pyrad.py --quit" to shutdown the process in the background. "pyrad.py --help" shows the usage. "pyrad.py --daemon" starts pyRad if without showing the GUI.
 
 """
 
@@ -62,6 +63,12 @@ ideas:
 - Add a CLI fallback, so people can also access their actions via the shell. 
 - Talk to DBus directly (for higher performance). -> dbus-send --type=method_call --dest=org.kde.pyRad /MainApplication org.kde.KUniqueApplication.newInstance
   (from http://www.staerk.de/thorsten/index.php/Hacking_KDE)
+- Keyboard shortcuts (1, 2, 3, ... for the wheel items -> click paths to programs)
+- Check if an app is already open. If it is, simply switch to it (dbus -> get winID, forceActivateWindow(winID)?). 
+  Sample DBus calls: dbus-send --dest=org.freedesktop.DBus --type=method_call --print-reply / org.freedesktop.DBus.ListNames ; dbus-send --dest=org.kde.konqueror-14040 --type=method_call --print-reply /konqueror/MainWindow_1 org.kde.KMainWindow.winId; dbus-send --dest=org.freedesktop.DBus --type=method_call --print-reply / org.freedesktop.DBus.NameHasOwner string:"org.kde.pyRad"
+  To bring a background app to foreground, hide its main window, then show it again.
+  -> /konqueror com.trolltech.Qt.QWidget.hide + ...show + hide pyRad
+  PID stuff: http://code.google.com/p/psutil/
 
 PyPI url: http://pypi.python.org/pypi/pyRadKDE
 """
@@ -91,12 +98,13 @@ __copyright__ = """pyRad - a wheel type command menu.
 ### Constants ###
 
 #: The PyRad version identifier
-__version__ = "0.3.3"
+__version__ = "0.4.0"
+appName = "pyRad"
 
 ### Commandline handling ###
 # we do this here to have the maximum reaction time. 
 from sys import argv
-if "--help" in argv:
+if __name__ == "__main__" and "--help" in argv:
     print __usage__
     exit()
 
@@ -160,7 +168,7 @@ class KUniqueCaller(KUniqueApplication):
 
 def createAboutData():
     """Create the aboutData for PyRad."""
-    appName     = "pyRad"
+    #appName     = "pyRad"
     catalog     = ""
     programName = ki18n ("Rad")
     version     = __version__
