@@ -50,6 +50,9 @@ DEFAULT_CONFIG = '''# v0.1 keep this line!
 ]
 '''
 
+#: The keys for accessing pyrad element via the keyboard
+SELECTION_KEYS_ORDERED = "0123456789abcdefghijklmnopqrstuvwxyz"
+
 ### Window ###
 
 class ItemEditWidget(QWidget):
@@ -188,7 +191,7 @@ class Rad(QWidget):
                 # If pyRad didn't reach a final action, we stop here.
                 if event.button() == Qt.LeftButton:
                     if self.labelClicked(i) is None:
-                        break
+                        break # TODO: Check if we can use return None instead
                 elif event.button() == Qt.RightButton and i != self.circle[0]:
                     self.editLabel(i)
                     break
@@ -205,6 +208,22 @@ class Rad(QWidget):
                 # Otherwise we can hide the pyRad
                 self.hide()
                 
+    def keyReleaseEvent(self, event):
+        """Select items via keyboard."""
+        # Debug: Don't react, if an edit dialog is open.
+        if self.editor.main.isVisible():
+            return None
+
+        key = str(event.text())
+        if key and key in SELECTION_KEYS_ORDERED[:len(self.circle)]:
+            idx = SELECTION_KEYS_ORDERED.index(key)
+            if not self.labelClicked(self.circle[idx]) is None:
+                self.hide()
+	else: 
+	    if event.key() == Qt.Key_Escape: 
+		self.hide()
+        
+
     def addLabelAfter(self, label): # -> open message box -> set item.icon and item.action. -> save_config()
         """Edit a label. A click on the center item promts for adding a new label."""
         # add a new label.
@@ -243,7 +262,7 @@ class Rad(QWidget):
         @return: True if the circle reached an end, None if it should continue existing."""
         if label.action is None:
             return True
-        if label.action is not None and label.action[0] == "[":
+        if label.action[0] == "[":
             # then it's a folder!
             # get its contents
             items = eval(label.action)
@@ -295,6 +314,7 @@ class Rad(QWidget):
         # Now set the center icon
         self.circle[0].move(0.5*self.width() - 0.25*self.circle[0].width(), 0.5*self.height() - 0.75*self.circle[0].height())
 
+        # TODO: Check QPainterPath -> circle by percentage. 
         # And finally arrange all other items in a circle around the center.
         for i in self.circle[1:]:
             angle = 2 * pi * (self.circle.index(i) -1 ) / len(self.circle[1:])
@@ -317,6 +337,14 @@ class Rad(QWidget):
         circle = []
         for icon, action in items:
             label = self.item_to_label(icon, action)
+            # we set the tooltip here,
+            # because it needs the position in the circle.
+            if SELECTION_KEYS_ORDERED[len(circle):]: 
+                key = SELECTION_KEYS_ORDERED[len(circle)]
+                toolTip =  key + " - " + str(action)
+            else:
+                toolTip = str(action)
+            label.setToolTip(toolTip)
             circle.append(label)
 
         return circle
@@ -326,7 +354,9 @@ class Rad(QWidget):
         label = QLabel(self)
         label.icon = icon
         label.action = action
-        label.setToolTip(str(action))
+        # The tooltip must be set outside this function,
+        # because it needs the position in te circle. 
+        # label.setToolTip(str(action))
         label.setPixmap(self.iconloader.loadIcon(icon, 0))
         return label
 
